@@ -133,9 +133,12 @@ Some flags are meant specifically for interactive use --- in particular,
 'test', 'tags' and 'fingerprint' are useful.
 
 '--test' runs once in the foreground with verbose logging, then exits.
-It also exits if it can't get a valid catalog. `--test` includes the '--detailed-exitcodes' option by default and exits with one of the following exit codes:
+It also exits if it can't get a valid catalog. `--test` includes the 
+'--detailed-exitcodes' option by default and exits with one of the following 
+exit codes:
 
-* 0: The run succeeded with no changes or failures; the system was already in the desired state.
+* 0: The run succeeded with no changes or failures; the system was already in 
+     the desired state.
 * 1: The run failed, or wasn't attempted due to another run already in progress.
 * 2: The run succeeded, and some resources were changed.
 * 4: The run succeeded, and some resources failed.
@@ -246,7 +249,9 @@ generated by running puppet agent with '--genconfig'.
   'puppet agent' exits after executing this.
   
 *  --evaltrace:
-  Logs each resource as it is being evaluated. This allows you to interactively see exactly what is being done. (This is a Puppet setting, and can go in puppet.conf. Note the special 'no-' prefix for boolean settings on the command line.)
+  Logs each resource as it is being evaluated. This allows you to interactively
+  see exactly what is being done. (This is a Puppet setting, and can go in
+  puppet.conf. Note the special 'no-' prefix for boolean settings on the command line.)
 
 * --fingerprint:
   Display the current certificate or certificate signing request
@@ -267,7 +272,8 @@ generated by running puppet agent with '--genconfig'.
   service), 'eventlog' (the Windows Event Log), 'console', or the path to a log
   file. If debugging or verbosity is enabled, this defaults to 'console'.
   Otherwise, it defaults to 'syslog' on POSIX systems and 'eventlog' on Windows.
-  Multiple destinations can be set using a comma separated list (eg: `/path/file1,console,/path/file2`)"
+  Multiple destinations can be set using a comma separated list 
+  (eg: `/path/file1,console,/path/file2`)"
 
   A path ending with '.json' will receive structured output in JSON format. The
   log file will not have an ending ']' automatically written to it due to the
@@ -310,7 +316,8 @@ generated by running puppet agent with '--genconfig'.
   'no-splay', and 'show_diff'.
   
 * --trace
-  Prints stack traces on some errors. (This is a Puppet setting, and can go in puppet.conf. Note the special 'no-' prefix for boolean settings on the command line.)
+  Prints stack traces on some errors. (This is a Puppet setting, and can go in
+  puppet.conf. Note the special 'no-' prefix for boolean settings on the command line.)
 
 * --verbose:
   Turn on verbose reporting.
