@@ -113,6 +113,8 @@ configuration options by running puppet with
   Where to send log messages. Choose between 'syslog' (the POSIX syslog
   service), 'eventlog' (the Windows Event Log), 'console', or the path to a log
   file. Defaults to 'console'.
+  Multiple destinations can be set using a comma separated list
+  (eg: `/path/file1,console,/path/file2`)"
 
   A path ending with '.json' will receive structured output in JSON format. The
   log file will not have an ending ']' automatically written to it due to the
@@ -190,7 +192,7 @@ Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
       text = Puppet::FileSystem.read(options[:catalog], :encoding => 'utf-8')
     end
     env = Puppet.lookup(:environments).get(Puppet[:environment])
-    Puppet.override(:current_environment => env, :loaders => Puppet::Pops::Loaders.new(env)) do
+    Puppet.override(:current_environment => env, :loaders => create_loaders(env)) do
       catalog = read_catalog(text)
       apply_catalog(catalog)
     end
@@ -204,7 +206,7 @@ Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
     apply_environment = get_configured_environment(node, manifest)
 
     # TRANSLATORS "puppet apply" is a program command and should not be translated
-    Puppet.override({:current_environment => apply_environment}, _("For puppet apply")) do
+    Puppet.override({:current_environment => apply_environment, :loaders => create_loaders(apply_environment)}, _("For puppet apply")) do
       configure_node_facts(node, facts)
 
       # Allow users to load the classes that puppet agent creates.
@@ -235,30 +237,23 @@ Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
           exit(1)
         end
 
-        # Loaders are required when resolving deferred values and at the end
-        # when apply_catalog is called - it is therefore used around all of the
-        # required steps as it is expensive to set up loaders twice (once for
-        # resolution and once for the apply).
-        #
-        exit_status = Puppet.override(:loaders => Puppet::Pops::Loaders.new(apply_environment)) do
+        # Resolve all deferred values and replace them / mutate the catalog
+        Puppet::Pops::Evaluator::DeferredResolver.resolve_and_replace(node.facts, catalog, apply_environment)
 
-          # Resolve all deferred values and replace them / mutate the catalog
-          Puppet::Pops::Evaluator::DeferredResolver.resolve_and_replace(node.facts, catalog)
+        # Translate it to a RAL catalog
+        catalog = catalog.to_ral
 
-          # Translate it to a RAL catalog
-          catalog = catalog.to_ral
+        catalog.finalize
 
-          catalog.finalize
+        catalog.retrieval_duration = Time.now - starttime
 
-          catalog.retrieval_duration = Time.now - starttime
-
-          if options[:write_catalog_summary]
-            catalog.write_class_file
-            catalog.write_resource_file
-          end
-
-          apply_catalog(catalog)
+        if options[:write_catalog_summary]
+          catalog.write_class_file
+          catalog.write_resource_file
         end
+
+        exit_status = apply_catalog(catalog)
+
         if not exit_status
           exit(1)
         elsif options[:detailed_exitcodes] then
@@ -313,6 +308,11 @@ Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
 
   private
 
+  def create_loaders(env)
+    # Ignore both 'cached_puppet_lib' and pcore resource type loaders
+    Puppet::Pops::Loaders.new(env, false, false)
+  end
+
   def read_catalog(text)
     facts = get_facts()
     node = get_node()
@@ -332,7 +332,7 @@ Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
         raise Puppet::Error, _("Could not deserialize catalog from %{format}: %{detail}") % { format: format, detail: detail }, detail.backtrace
       end
       # Resolve all deferred values and replace them / mutate the catalog
-      Puppet::Pops::Evaluator::DeferredResolver.resolve_and_replace(node.facts, catalog)
+      Puppet::Pops::Evaluator::DeferredResolver.resolve_and_replace(node.facts, catalog, configured_environment)
 
       catalog.to_ral
     end
