@@ -23,8 +23,8 @@ module Puppet::Network
       end
     end
 
-    def initialize
-      @resolver = Resolv::DNS.new
+    def initialize(resolver = Resolv::DNS.new)
+      @resolver = resolver
 
       # Stores DNS records per service, along with their TTL
       # and the time at which they were resolved, for cache
@@ -50,7 +50,7 @@ module Puppet::Network
       case service_name
         when :puppet then service = '_x-puppet'
         when :file   then service = '_x-puppet-fileserver'
-        else              service = "_x-puppet-#{service_name.to_s}"
+        else              service = "_x-puppet-#{service_name}"
       end
       record_name = "#{service}._tcp.#{domain}"
 
@@ -72,7 +72,7 @@ module Puppet::Network
       else
         each_priority(records) do |recs|
           while next_rr = recs.delete(find_weighted_server(recs)) #rubocop:disable Lint/AssignmentInCondition
-            Puppet.debug "Yielding next server of #{next_rr.target.to_s}:#{next_rr.port}"
+            Puppet.debug "Yielding next server of #{next_rr.target}:#{next_rr.port}"
             yield next_rr.target.to_s, next_rr.port
           end
         end
